Band Structure — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Band Structure

These examples demonstrate the band structure plotting capabilities.

Autobands plotting

Autobands plotting

Plotting non colinear band structures in VASP

Plotting non colinear band structures in VASP

Plotting non colinear band structures in Quantum Espresso

Plotting non colinear band structures in Quantum Espresso

Plotting Atomic Levels

Plotting Atomic Levels

Plotting Inverse participation ratio

Plotting Inverse participation ratio

Comparing band structures

Comparing band structures

Unfolding Band Structure

Unfolding Band Structure

Plotting spin polarized band structures

Plotting spin polarized band structures

Plotting band structure

Plotting band structure

Plotting 2D band structure

Plotting 2D band structure

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar